1
0
mirror of git://projects.qi-hardware.com/openwrt-xburst.git synced 2024-11-27 17:55:55 +02:00

reset to backfire.

This commit is contained in:
Lars-Peter Clausen 2010-05-02 15:37:57 +02:00
parent 78fcab66df
commit 99c6c73272
65 changed files with 1478 additions and 1621 deletions

View File

@ -18,32 +18,13 @@ KDIR=$(KERNEL_BUILD_DIR)
IMG_PREFIX:=openwrt-$(BOARD)$(if $(SUBTARGET),-$(SUBTARGET))
ifneq ($(CONFIG_BIG_ENDIAN),y)
JFFS2OPTS := --pad --little-endian --squash -v
JFFS2OPTS := --pad --little-endian --squash
SQUASHFS_OPTS := -le
else
JFFS2OPTS := --pad --big-endian --squash -v
JFFS2OPTS := --pad --big-endian --squash
SQUASHFS_OPTS := -be
endif
ifeq ($(CONFIG_JFFS2_RTIME),y)
JFFS2OPTS+= -X rtime
endif
ifeq ($(CONFIG_JFFS2_ZLIB),y)
JFFS2OPTS+= -X zlib
endif
ifeq ($(CONFIG_JFFS2_LZMA),y)
JFFS2OPTS+= -X lzma --compression-mode=size
endif
ifneq ($(CONFIG_JFFS2_RTIME),y)
JFFS2OPTS+= -x rtime
endif
ifneq ($(CONFIG_JFFS2_ZLIB),y)
JFFS2OPTS+= -x zlib
endif
ifneq ($(CONFIG_JFFS2_LZMA),y)
JFFS2OPTS+= -x lzma
endif
ifneq ($(CONFIG_LINUX_2_4)$(CONFIG_LINUX_2_6_25),)
USE_SQUASHFS3 := y
endif
@ -78,7 +59,7 @@ ifneq ($(CONFIG_TARGET_ROOTFS_INITRAMFS),y)
ifeq ($(CONFIG_TARGET_ROOTFS_JFFS2),y)
define Image/mkfs/jffs2/sub
# FIXME: removing this line will cause strange behaviour in the foreach loop below
$(STAGING_DIR_HOST)/bin/mkfs.jffs2 $(JFFS2OPTS) -e $(patsubst %k,%KiB,$(1)) -o $(KDIR)/root.jffs2-$(1) -d $(TARGET_DIR) -v 2>&1 1>/dev/null | awk '/^.+$$$$/'
$(STAGING_DIR_HOST)/bin/mkfs.jffs2 $(JFFS2OPTS) -e $(patsubst %k,%KiB,$(1)) -o $(KDIR)/root.jffs2-$(1) -d $(TARGET_DIR)
$(call add_jffs2_mark,$(KDIR)/root.jffs2-$(1))
$(call Image/Build,jffs2-$(1))
endef

View File

@ -97,8 +97,9 @@ define Kernel/Configure/2.6
endef
define Kernel/Configure/Default
$(LINUX_CONFCMD) > $(LINUX_DIR)/.config.target
# copy CONFIG_KERNEL_* settings over to .config.target
awk '/^(#[[:space:]]+)?CONFIG_KERNEL/{sub("CONFIG_KERNEL_","CONFIG_");print}' $(TOPDIR)/.config >> $(LINUX_DIR)/.config.target
echo "$(if $(CONFIG_KERNEL_KALLSYMS),CONFIG_KALLSYMS=y,# CONFIG_KALLSYMS is not set)" >> $(LINUX_DIR)/.config.target
echo "$(if $(CONFIG_KERNEL_PROFILING),CONFIG_PROFILING=y,# CONFIG_PROFILING is not set)" >> $(LINUX_DIR)/.config.target
echo "$(if $(CONFIG_KERNEL_DEBUG_FS),CONFIG_DEBUG_FS=y,# CONFIG_DEBUG_FS is not set)" >> $(LINUX_DIR)/.config.target
echo "# CONFIG_KALLSYMS_EXTRA_PASS is not set" >> $(LINUX_DIR)/.config.target
echo "# CONFIG_KALLSYMS_ALL is not set" >> $(LINUX_DIR)/.config.target
echo "# CONFIG_KPROBES is not set" >> $(LINUX_DIR)/.config.target

View File

@ -20,21 +20,12 @@ endif
ifeq ($(LINUX_VERSION),2.6.32.10)
LINUX_KERNEL_MD5SUM:=5d996507ad482a3a8c8e6b2d48e7994b
endif
ifeq ($(LINUX_VERSION),2.6.32.11)
LINUX_KERNEL_MD5SUM:=3709c691d909b4f8ca692edc6c726cb6
endif
ifeq ($(LINUX_VERSION),2.6.33)
LINUX_KERNEL_MD5SUM:=c3883760b18d50e8d78819c54d579b00
endif
ifeq ($(LINUX_VERSION),2.6.33.1)
LINUX_KERNEL_MD5SUM:=73b514ec918b88a45656be191b1ee226
endif
ifeq ($(LINUX_VERSION),2.6.33.2)
LINUX_KERNEL_MD5SUM:=80c5ff544b0ee4d9b5d8b8b89d4a0ef9
endif
ifeq ($(LINUX_VERSION),2.6.34-rc4)
LINUX_KERNEL_MD5SUM:=45b185f33300bbd69034779748b52c5f
endif
# disable the md5sum check for unknown kernel versions
LINUX_KERNEL_MD5SUM?=x

View File

@ -1,10 +1,4 @@
# uncomment me to log hotplug events
# DEVPATH is set {
# nothrottle
# exec logger -s -t hotplug -p daemon.info "name=%DEVICENAME%, path=%DEVPATH%"
# }
DEVICENAME ~~ (null|full|ptmx|tty|zero|gpio|hvc) {
nothrottle
makedev /dev/%DEVICENAME% 0666

View File

@ -10,12 +10,7 @@ run_scripts() {
LOGGER="cat"
[ -x /usr/bin/logger ] && LOGGER="logger -s -p 6 -t sysinit"
. /etc/functions.sh
config_load system
config_get_bool foreground system foreground no
if [ "$1" = "S" -a "$foreground" != "yes" ]; then
if [ "$1" = "S" ]; then
run_scripts "$1" "$2" &
else
run_scripts "$1" "$2"

View File

@ -60,7 +60,6 @@ enum {
WRT54G,
WRTSL54GS,
WRT54G3G,
WRT54G3GV2_VF,
WRT160N,
WRT300NV11,
WRT350N,
@ -272,18 +271,6 @@ static struct platform_t __initdata platforms[] = {
{ .name = "3g_blink", .gpio = 1 << 5, .polarity = NORMAL },
},
},
[WRT54G3GV2_VF] = {
.name = "Linksys WRT54G3GV2-VF",
.buttons = {
{ .name = "reset", .gpio = 1 << 6 },
{ .name = "3g", .gpio = 1 << 4 },
},
.leds = {
{ .name = "power", .gpio = 1 << 1, .polarity = NORMAL },
{ .name = "3g_green", .gpio = 1 << 2, .polarity = NORMAL },
{ .name = "3g_blue", .gpio = 1 << 3, .polarity = NORMAL },
},
},
[WRT160N] = {
.name = "Linksys WRT160N",
.buttons = {
@ -996,9 +983,6 @@ static struct platform_t __init *platform_detect(void)
if (!strcmp(boardtype, "0x0101") && !strcmp(getvar("boot_ver"), "v3.6"))
return &platforms[WRT54G3G];
if (!strcmp(boardtype, "0x042f") && !strcmp(getvar("model_name"), "WRT54G3GV2-VF"))
return &platforms[WRT54G3GV2_VF];
if (!strcmp(getvar("et1phyaddr"),"5") && !strcmp(getvar("et1mdcport"), "1"))
return &platforms[WRTSL54GS];

View File

@ -29,23 +29,6 @@ config BUSYBOX_CONFIG_EXTRA_COMPAT
some GNU extensions in libc. You probably only need this option
if you plan to run busybox on desktop.
config BUSYBOX_CONFIG_INCLUDE_SUSv2
bool "Enable obsolete features removed before SUSv3"
default y
help
This option will enable backwards compatibility with SuSv2,
specifically, old-style numeric options ('command -1 <file>')
will be supported in head, tail, and fold. (Note: should
affect renice too.)
config BUSYBOX_CONFIG_USE_PORTABLE_CODE
bool "Avoid using GCC-specific code constructs"
default n
help
Use this option if you are trying to compile busybox with
compiler other than gcc.
If you do use gcc, this option may needlessly increase code size.
choice
prompt "Buffer allocation policy"
default BUSYBOX_CONFIG_FEATURE_BUFFERS_GO_ON_STACK
@ -519,8 +502,17 @@ config BUSYBOX_CONFIG_EFENCE
endchoice
config BUSYBOX_CONFIG_INCLUDE_SUSv2
bool "Enable obsolete features removed before SUSv3?"
default y
help
This option will enable backwards compatibility with SuSv2,
specifically, old-style numeric options ('command -1 <file>')
will be supported in head, tail, and fold. (Note: should
affect renice too.)
### config PARSE
### bool "Uniform config file parser debugging applet: parse"
### bool "Uniform config file parser debugging applet: parse"
endmenu

View File

@ -165,13 +165,6 @@ config BUSYBOX_CONFIG_GZIP
gzip is used to compress files.
It's probably the most widely used UNIX compression program.
config BUSYBOX_CONFIG_FEATURE_GZIP_LONG_OPTIONS
bool "Enable long options"
default n
depends on BUSYBOX_CONFIG_GZIP && BUSYBOX_CONFIG_LONG_OPTS
help
Enable use of long options, increases size by about 106 Bytes
config BUSYBOX_CONFIG_LZOP
bool "lzop"
default n
@ -276,14 +269,6 @@ config BUSYBOX_CONFIG_FEATURE_TAR_UNAME_GNAME
listings (-t) and preserving permissions when unpacking (-p).
+200 bytes.
config BUSYBOX_CONFIG_FEATURE_TAR_NOPRESERVE_TIME
bool "Enable -m (do not preserve time) option"
default n
depends on BUSYBOX_CONFIG_TAR
help
With this option busybox supports GNU tar -m
(do not preserve time) option.
endif #tar
config BUSYBOX_CONFIG_UNCOMPRESS

View File

@ -52,13 +52,6 @@ config BUSYBOX_CONFIG_CHOWN
chown is used to change the user and/or group ownership
of files.
config BUSYBOX_CONFIG_FEATURE_CHOWN_LONG_OPTIONS
bool "Enable long options"
default n
depends on BUSYBOX_CONFIG_CHOWN && BUSYBOX_CONFIG_LONG_OPTS
help
Enable use of long options
config BUSYBOX_CONFIG_CHROOT
bool "chroot"
default y
@ -85,14 +78,6 @@ config BUSYBOX_CONFIG_CP
help
cp is used to copy files and directories.
config BUSYBOX_CONFIG_FEATURE_CP_LONG_OPTIONS
bool "Enable long options for cp"
default n
depends on BUSYBOX_CONFIG_CP && BUSYBOX_CONFIG_LONG_OPTS
help
Enable long options for cp.
Also add support for --parents option.
config BUSYBOX_CONFIG_CUT
bool "cut"
default y
@ -115,22 +100,6 @@ config BUSYBOX_CONFIG_FEATURE_DATE_ISOFMT
Enable option (-I) to output an ISO-8601 compliant
date/time string.
config BUSYBOX_CONFIG_FEATURE_DATE_COMPAT
bool "Support weird 'date MMDDhhmm[[YY]YY][.ss]' format"
default n
depends on BUSYBOX_CONFIG_DATE
help
System time can be set by 'date -s DATE' and simply 'date DATE',
but formats of DATE string are different. 'date DATE' accepts
a rather weird MMDDhhmm[[YY]YY][.ss] format with completely
unnatural placement of year between minutes and seconds.
date -s (and other commands like touch -d) use more sensible
formats (for one, ISO format YYYY-MM-DD hh:mm:ss.ssssss).
With this option off, 'date DATE' is 'date -s DATE' support
the same format. With it on, 'date DATE' additionally supports
MMDDhhmm[[YY]YY][.ss] format.
config BUSYBOX_CONFIG_DD
bool "dd"
default y
@ -144,22 +113,13 @@ config BUSYBOX_CONFIG_FEATURE_DD_SIGNAL_HANDLING
default y
depends on BUSYBOX_CONFIG_DD
help
Sending a SIGUSR1 signal to a running `dd' process makes it
sending a SIGUSR1 signal to a running `dd' process makes it
print to standard error the number of records read and written
so far, then to resume copying.
$ dd if=/dev/zero of=/dev/null&
$ pid=$! kill -USR1 $pid; sleep 1; kill $pid
10899206+0 records in
10899206+0 records out
config BUSYBOX_CONFIG_FEATURE_DD_THIRD_STATUS_LINE
bool "Enable the third status line upon signal"
default n
depends on BUSYBOX_CONFIG_DD && BUSYBOX_CONFIG_FEATURE_DD_SIGNAL_HANDLING
help
Displays a coreutils-like third status line with transferred bytes,
elapsed time and speed.
10899206+0 records in 10899206+0 records out
config BUSYBOX_CONFIG_FEATURE_DD_IBS_OBS
bool "Enable ibs, obs and conv options"
@ -869,13 +829,13 @@ config BUSYBOX_CONFIG_FEATURE_HUMAN_READABLE
help
Allow df, du, and ls to have human readable output.
comment "Common options for md5sum, sha1sum, sha256sum, sha512sum"
depends on BUSYBOX_CONFIG_MD5SUM || BUSYBOX_CONFIG_SHA1SUM || BUSYBOX_CONFIG_SHA256SUM || BUSYBOX_CONFIG_SHA512SUM
comment "Common options for md5sum, sha1sum"
depends on BUSYBOX_CONFIG_MD5SUM || BUSYBOX_CONFIG_SHA1SUM
config BUSYBOX_CONFIG_FEATURE_MD5_SHA1_SUM_CHECK
bool "Enable -c, -s and -w options"
default y
depends on BUSYBOX_CONFIG_MD5SUM || BUSYBOX_CONFIG_SHA1SUM || BUSYBOX_CONFIG_SHA256SUM || BUSYBOX_CONFIG_SHA512SUM
depends on BUSYBOX_CONFIG_MD5SUM || BUSYBOX_CONFIG_SHA1SUM
help
Enabling the -c options allows files to be checked
against pre-calculated hash values.

View File

@ -35,12 +35,13 @@ config BUSYBOX_CONFIG_DIFF
differences between them in a form that can be given to
the patch command.
config BUSYBOX_CONFIG_FEATURE_DIFF_LONG_OPTIONS
bool "Enable long options"
config BUSYBOX_CONFIG_FEATURE_DIFF_BINARY
bool "Enable checks for binary files"
default n
depends on BUSYBOX_CONFIG_DIFF && BUSYBOX_CONFIG_LONG_OPTS
depends on BUSYBOX_CONFIG_DIFF
help
Enable use of long options.
This option enables support for checking for binary files
before a comparison is carried out.
config BUSYBOX_CONFIG_FEATURE_DIFF_DIR
bool "Enable directory support"
@ -50,6 +51,14 @@ config BUSYBOX_CONFIG_FEATURE_DIFF_DIR
This option enables support for directory and subdirectory
comparison.
config BUSYBOX_CONFIG_FEATURE_DIFF_MINIMAL
bool "Enable -d option to find smaller sets of changes"
default n
depends on BUSYBOX_CONFIG_DIFF
help
Enabling this option allows the use of -d to make diff
try hard to find the smallest possible set of changes.
config BUSYBOX_CONFIG_ED
bool "ed"
default n

View File

@ -171,13 +171,6 @@ config BUSYBOX_CONFIG_FEATURE_FIND_CONTEXT
help
Support the 'find -context' option for matching security context.
config BUSYBOX_CONFIG_FEATURE_FIND_LINKS
bool "Enable -links: link count matching"
default n
depends on BUSYBOX_CONFIG_FIND
help
Support the 'find -links' option for matching number of links.
config BUSYBOX_CONFIG_GREP
bool "grep"
default y

View File

@ -111,7 +111,7 @@ config BUSYBOX_CONFIG_FEATURE_EDITING_ASK_TERMINAL
current cursor position. This information is used to make line
editing more robust in some cases.
If you are not sure whether your terminals respond to this code
correctly, or want to save on code size (about 400 bytes),
correctly, or want to save on code size (about 300 bytes),
then do not turn this option on.
config BUSYBOX_CONFIG_FEATURE_NON_POSIX_CP
@ -134,8 +134,9 @@ config BUSYBOX_CONFIG_FEATURE_VERBOSE_CP_MESSAGE
$ cp file /vmlinuz/file
cp: cannot stat '/vmlinuz/file': Path has non-directory component
If this feature is not enabled, they will be, respectively:
cp: cannot create '/does_not_exist/file': No such file or directory
cp: cannot remove '/does_not_exist/file': No such file or directory
cp: cannot stat '/vmlinuz/file': Not a directory
respectively.
This will cost you ~60 bytes.
config BUSYBOX_CONFIG_FEATURE_COPYBUF_KB

View File

@ -137,11 +137,11 @@ config BUSYBOX_CONFIG_FEATURE_CROND_D
-d sets loglevel to 0 (most verbose) and directs all output to stderr.
config BUSYBOX_CONFIG_FEATURE_CROND_CALL_SENDMAIL
bool "Report command output via email (using sendmail)"
bool "Using /usr/sbin/sendmail?"
default n
depends on BUSYBOX_CONFIG_CROND
help
Command output will be sent to corresponding user via email.
Support calling /usr/sbin/sendmail for send cmd outputs.
config BUSYBOX_CONFIG_FEATURE_CROND_DIR
string "crond spool directory"
@ -272,13 +272,6 @@ config BUSYBOX_CONFIG_FBSPLASH
"NN" (ASCII decimal number) - percentage to show on progress bar
"exit" - well you guessed it
config BUSYBOX_CONFIG_FLASHCP
bool "flashcp"
default n
help
The flashcp binary, inspired by mtd-utils as of git head 5eceb74f7.
This utility is used to copy images into a MTD device.
config BUSYBOX_CONFIG_FLASH_LOCK
bool "flash_lock"
default n
@ -625,12 +618,6 @@ config BUSYBOX_CONFIG_VOLNAME
help
Prints a CD-ROM volume name.
config BUSYBOX_CONFIG_WALL
bool "wall"
default n
help
Write a message to all users that are logged in.
config BUSYBOX_CONFIG_WATCHDOG
bool "watchdog"
default y

View File

@ -121,22 +121,6 @@ config BUSYBOX_CONFIG_FEATURE_2_4_MODULES
This increases size considerably. Say N unless you plan
to run ancient kernels.
config BUSYBOX_CONFIG_FEATURE_INSMOD_TRY_MMAP
bool "Try to load module from a mmap'ed area"
default n
depends on BUSYBOX_CONFIG_INSMOD || BUSYBOX_CONFIG_MODPROBE_SMALL
help
This option causes module loading code to try to mmap
module first. If it does not work (for example,
it does not work for compressed modules), module will be read
(and unpacked if needed) into a memory block allocated by malloc.
The only case when mmap works but malloc does not is when
you are trying to load a big module on a very memory-constrained
machine. Malloc will momentarily need 2x as much memory as mmap.
Choosing N saves about 250 bytes of code (on 32-bit x86).
config BUSYBOX_CONFIG_FEATURE_INSMOD_VERSION_CHECKING
bool "Enable module version checking"
default n

View File

@ -117,17 +117,6 @@ config BUSYBOX_CONFIG_FEATURE_FTP_WRITE
help
Enable all kinds of FTP upload commands (-w option)
config BUSYBOX_CONFIG_FEATURE_FTPD_ACCEPT_BROKEN_LIST
bool "Enable workaround for RFC-violating clients"
default n
depends on BUSYBOX_CONFIG_FTPD
help
Some ftp-clients (among them KDE's Konqueror) issue illegal
"LIST -la" requests. This option works around those problems.
It might prevent you from listing files starting with "-" and
it increases the code size by ~40 bytes.
Most other ftp servers seem to behave similar to this.
config BUSYBOX_CONFIG_FTPGET
bool "ftpget"
default n
@ -678,20 +667,6 @@ config BUSYBOX_CONFIG_NSLOOKUP
help
nslookup is a tool to query Internet name servers.
config BUSYBOX_CONFIG_NTPD
bool "ntpd"
default n
help
The NTP client/server daemon.
config BUSYBOX_CONFIG_FEATURE_NTPD_SERVER
bool "Make ntpd usable as a NTP server"
default n
depends on BUSYBOX_CONFIG_NTPD
help
Make ntpd usable as a NTP server. If you disable this option
ntpd will be usable only as a NTP client.
config BUSYBOX_CONFIG_PING
bool "ping"
default y
@ -819,27 +794,6 @@ config BUSYBOX_CONFIG_FEATURE_TELNETD_STANDALONE
help
Selecting this will make telnetd able to run standalone.
config BUSYBOX_CONFIG_FEATURE_TELNETD_INETD_WAIT
bool "Support -w SEC option (inetd wait mode)"
default n
depends on BUSYBOX_CONFIG_FEATURE_TELNETD_STANDALONE
help
This option allows you to run telnetd in "inet wait" mode.
Example inetd.conf line (note "wait", not usual "nowait"):
telnet stream tcp wait root /bin/telnetd telnetd -w10
In this example, inetd passes _listening_ socket_ as fd 0
to telnetd when connection appears.
telnetd will wait for connections until all existing
connections are closed, and no new connections
appear during 10 seconds. Then it exits, and inetd continues
to listen for new connections.
This option is rarely used. "tcp nowait" is much more usual
way of running tcp services, including telnetd.
You most probably want to say N here.
config BUSYBOX_CONFIG_TFTP
bool "tftp"
default n
@ -877,19 +831,12 @@ config BUSYBOX_CONFIG_FEATURE_TFTP_PUT
Also enable download support in tftpd, if tftpd is selected.
config BUSYBOX_CONFIG_FEATURE_TFTP_BLOCKSIZE
bool "Enable 'blksize' and 'tsize' protocol options"
bool "Enable \"blksize\" protocol option"
default n
depends on BUSYBOX_CONFIG_TFTP || BUSYBOX_CONFIG_TFTPD
help
Allow tftp to specify block size, and tftpd to understand
"blksize" and "tsize" options.
config BUSYBOX_CONFIG_FEATURE_TFTP_PROGRESS_BAR
bool "Enable tftp progress meter"
default n
depends on BUSYBOX_CONFIG_TFTP && BUSYBOX_CONFIG_FEATURE_TFTP_BLOCKSIZE
help
Show progress bar.
"blksize" option.
config BUSYBOX_CONFIG_TFTP_DEBUG
bool "Enable debug"
@ -905,13 +852,6 @@ config BUSYBOX_CONFIG_TRACEROUTE
help
Utility to trace the route of IP packets.
config BUSYBOX_CONFIG_TRACEROUTE6
bool "traceroute6"
default n
depends on BUSYBOX_CONFIG_FEATURE_IPV6 && BUSYBOX_CONFIG_TRACEROUTE
help
Utility to trace the route of IPv6 packets.
config BUSYBOX_CONFIG_FEATURE_TRACEROUTE_VERBOSE
bool "Enable verbose output"
default y
@ -940,7 +880,7 @@ source package/busybox/config/networking/udhcp/Config.in
config BUSYBOX_CONFIG_IFUPDOWN_UDHCPC_CMD_OPTIONS
string "ifup udhcpc command line options"
default "-R -n"
depends on BUSYBOX_CONFIG_IFUPDOWN && BUSYBOX_CONFIG_UDHCPC
depends on BUSYBOX_CONFIG_IFUPDOWN && BUSYBOX_CONFIG_APP_UDHCPC
help
Command line options to pass to udhcpc from ifup.
Intended to alter options not available in /etc/network/interfaces.

View File

@ -3,26 +3,26 @@
# see scripts/kbuild/config-language.txt.
#
config BUSYBOX_CONFIG_UDHCPD
config BUSYBOX_CONFIG_APP_UDHCPD
bool "udhcp server (udhcpd)"
default n
help
udhcpd is a DHCP server geared primarily toward embedded systems,
while striving to be fully functional and RFC compliant.
config BUSYBOX_CONFIG_DHCPRELAY
config BUSYBOX_CONFIG_APP_DHCPRELAY
bool "dhcprelay"
default n
depends on BUSYBOX_CONFIG_UDHCPD
depends on BUSYBOX_CONFIG_APP_UDHCPD
help
dhcprelay listens for dhcp requests on one or more interfaces
and forwards these requests to a different interface or dhcp
server.
config BUSYBOX_CONFIG_DUMPLEASES
config BUSYBOX_CONFIG_APP_DUMPLEASES
bool "Lease display utility (dumpleases)"
default n
depends on BUSYBOX_CONFIG_UDHCPD
depends on BUSYBOX_CONFIG_APP_UDHCPD
help
dumpleases displays the leases written out by the udhcpd server.
Lease times are stored in the file by time remaining in lease, or
@ -31,7 +31,7 @@ config BUSYBOX_CONFIG_DUMPLEASES
config BUSYBOX_CONFIG_FEATURE_UDHCPD_WRITE_LEASES_EARLY
bool "Rewrite the lease file at every new acknowledge"
default n
depends on BUSYBOX_CONFIG_UDHCPD
depends on BUSYBOX_CONFIG_APP_UDHCPD
help
If selected, udhcpd will write a new file with leases every
time a new lease has been accepted, thus eliminating the need
@ -41,12 +41,12 @@ config BUSYBOX_CONFIG_FEATURE_UDHCPD_WRITE_LEASES_EARLY
config BUSYBOX_CONFIG_DHCPD_LEASES_FILE
string "Absolute path to lease file"
default "/var/run/udhcpd.leases"
depends on BUSYBOX_CONFIG_UDHCPD
depends on BUSYBOX_CONFIG_APP_UDHCPD
help
udhcpd stores addresses in a lease file. This is the absolute path
of the file. Normally it is safe to leave it untouched.
config BUSYBOX_CONFIG_UDHCPC
config BUSYBOX_CONFIG_APP_UDHCPC
bool "udhcp client (udhcpc)"
default y
help
@ -59,7 +59,7 @@ config BUSYBOX_CONFIG_UDHCPC
config BUSYBOX_CONFIG_FEATURE_UDHCPC_ARPING
bool "Verify that the offered address is free, using ARP ping"
default n
depends on BUSYBOX_CONFIG_UDHCPC
depends on BUSYBOX_CONFIG_APP_UDHCPC
help
If selected, udhcpc will send ARP probes and make sure
the offered address is really not in use by anyone. The client
@ -69,7 +69,7 @@ config BUSYBOX_CONFIG_FEATURE_UDHCPC_ARPING
config BUSYBOX_CONFIG_FEATURE_UDHCP_PORT
bool "Enable '-P port' option for udhcpd and udhcpc"
default n
depends on BUSYBOX_CONFIG_UDHCPD || BUSYBOX_CONFIG_UDHCPC
depends on BUSYBOX_CONFIG_APP_UDHCPD || BUSYBOX_CONFIG_APP_UDHCPC
help
At the cost of ~300 bytes, enables -P port option.
This feature is typically not needed.
@ -78,7 +78,7 @@ config BUSYBOX_CONFIG_UDHCP_DEBUG
int "Maximum verbosity level for udhcp applets (0..9)"
default 0
range 0 9
depends on BUSYBOX_CONFIG_UDHCPD || BUSYBOX_CONFIG_UDHCPC || BUSYBOX_CONFIG_DHCPRELAY
depends on BUSYBOX_CONFIG_APP_UDHCPD || BUSYBOX_CONFIG_APP_UDHCPC || BUSYBOX_CONFIG_APP_DHCPRELAY
help
Verbosity can be increased with multiple -v options.
This options controls how high it can be cranked up.
@ -89,7 +89,7 @@ config BUSYBOX_CONFIG_UDHCP_DEBUG
config BUSYBOX_CONFIG_FEATURE_UDHCP_RFC3397
bool "Support for RFC3397 domain search (experimental)"
default y
depends on BUSYBOX_CONFIG_UDHCPD || BUSYBOX_CONFIG_UDHCPC
depends on BUSYBOX_CONFIG_APP_UDHCPD || BUSYBOX_CONFIG_APP_UDHCPC
help
If selected, both client and server will support passing of domain
search lists via option 119, specified in RFC3397.
@ -97,7 +97,7 @@ config BUSYBOX_CONFIG_FEATURE_UDHCP_RFC3397
config BUSYBOX_CONFIG_UDHCPC_DEFAULT_SCRIPT
string "Absolute path to config script"
default "/usr/share/udhcpc/default.script"
depends on BUSYBOX_CONFIG_UDHCPC
depends on BUSYBOX_CONFIG_APP_UDHCPC
help
This script is called after udhcpc receives an answer. See
examples/udhcp for a working example. Normally it is safe
@ -107,7 +107,7 @@ config BUSYBOX_CONFIG_UDHCPC_SLACK_FOR_BUGGY_SERVERS
int "DHCP options slack buffer size"
default 80
range 0 924
depends on BUSYBOX_CONFIG_UDHCPD || BUSYBOX_CONFIG_UDHCPC
depends on BUSYBOX_CONFIG_APP_UDHCPD || BUSYBOX_CONFIG_APP_UDHCPC
help
Some buggy DHCP servers send DHCP offer packets with option
field larger than we expect (which might also be considered a

View File

@ -188,13 +188,6 @@ config BUSYBOX_CONFIG_FEATURE_TOPMEM
help
Enable 's' in top (gives lots of memory info).
config BUSYBOX_CONFIG_FEATURE_SHOW_THREADS
bool "Support for showing threads in ps/top"
default n
depends on BUSYBOX_CONFIG_PS || BUSYBOX_CONFIG_TOP
help
Enables ps -T option and 'h' command in top
config BUSYBOX_CONFIG_UPTIME
bool "uptime"
default y
@ -210,4 +203,5 @@ config BUSYBOX_CONFIG_WATCH
watch is used to execute a program periodically, showing
output to the screen.
endmenu

View File

@ -15,7 +15,6 @@ choice
config BUSYBOX_CONFIG_FEATURE_SH_IS_ASH
select BUSYBOX_CONFIG_ASH
bool "ash"
depends on !BUSYBOX_CONFIG_NOMMU
config BUSYBOX_CONFIG_FEATURE_SH_IS_HUSH
select BUSYBOX_CONFIG_HUSH
@ -37,7 +36,6 @@ endchoice
config BUSYBOX_CONFIG_ASH
bool "ash"
default y
depends on !BUSYBOX_CONFIG_NOMMU
help
Tha 'ash' shell adds about 60k in the default configuration and is
the most complete and most pedantically correct shell included with
@ -59,6 +57,23 @@ config BUSYBOX_CONFIG_ASH_JOB_CONTROL
help
Enable job control in the ash shell.
config BUSYBOX_CONFIG_ASH_READ_NCHARS
bool "'read -n N' and 'read -s' support"
default n
depends on BUSYBOX_CONFIG_ASH
help
'read -n N' will return a value after N characters have been read.
'read -s' will read without echoing the user's input.
config BUSYBOX_CONFIG_ASH_READ_TIMEOUT
bool "'read -t S' support"
default y
depends on BUSYBOX_CONFIG_ASH
help
'read -t S' will return a value after S seconds have passed.
This implementation will allow fractional seconds, expressed
as a decimal fraction, e.g. 'read -t 2.5 foo'.
config BUSYBOX_CONFIG_ASH_ALIAS
bool "alias support"
default y
@ -172,7 +187,7 @@ config BUSYBOX_CONFIG_HUSH_INTERACTIVE
help
Enable interactive mode (prompt and command editing).
Without this, hush simply reads and executes commands
from stdin just like a shell script from a file.
from stdin just like a shell script from the file.
No prompt, no PS1/PS2 magic shell variables.
config BUSYBOX_CONFIG_HUSH_JOB
@ -235,14 +250,6 @@ config BUSYBOX_CONFIG_HUSH_EXPORT_N
help
Enable support for export '-n' option in hush. It is a bash extension.
config BUSYBOX_CONFIG_HUSH_RANDOM_SUPPORT
bool "Pseudorandom generator and $RANDOM variable"
default n
depends on BUSYBOX_CONFIG_HUSH
help
Enable pseudorandom generator and dynamic variable "$RANDOM".
Each read of "$RANDOM" will generate a new pseudorandom value.
config BUSYBOX_CONFIG_LASH
bool "lash (deprecated: aliased to hush)"
default n

View File

@ -1,12 +1,12 @@
--- a/applets/Kbuild
+++ b/applets/Kbuild
@@ -28,13 +28,13 @@ HOSTCFLAGS_usage_pod.o = -I$(srctree_sla
@@ -27,13 +27,13 @@ HOSTCFLAGS_usage.o = -I$(srctree_slash)i
applets/applets.o: include/usage_compressed.h include/applet_tables.h
applets/applet_tables: .config $(srctree_slash)include/applets.h
-applets/usage: .config $(srctree_slash)include/applets.h
+applets/usage: .config $(srctree_slash)include/applets.h include/autoconf.h
applets/usage_pod: .config include/applet_tables.h $(srctree_slash)include/applets.h
-applets/usage: .config $(srctree_slash)applets/usage_compressed
+applets/usage: .config $(srctree_slash)applets/usage_compressed include/autoconf.h
applets/applet_tables: .config
quiet_cmd_gen_usage_compressed = GEN include/usage_compressed.h
cmd_gen_usage_compressed = $(srctree_slash)applets/usage_compressed include/usage_compressed.h applets

View File

@ -1,6 +1,6 @@
--- a/init/init.c
+++ b/init/init.c
@@ -456,8 +456,11 @@ static void run_actions(int action_type)
@@ -451,8 +451,11 @@ static void run_actions(int action_type)
/* Only run stuff with pid == 0. If pid != 0,
* it is already running
*/

View File

@ -1,6 +1,6 @@
--- a/networking/wget.c
+++ b/networking/wget.c
@@ -543,7 +543,7 @@ int wget_main(int argc UNUSED_PARAM, cha
@@ -653,7 +653,7 @@ int wget_main(int argc UNUSED_PARAM, cha
// "tries\0" Required_argument "t"
// "timeout\0" Required_argument "T"
/* Ignored (we always use PASV): */
@ -8,4 +8,4 @@
+ "passive-ftp\0" No_argument "\xfd"
"header\0" Required_argument "\xfe"
"post-data\0" Required_argument "\xfd"
/* Ignored (we don't do ssl) */
;

View File

@ -1,6 +1,6 @@
--- a/shell/ash.c
+++ b/shell/ash.c
@@ -12340,8 +12340,17 @@ exportcmd(int argc UNUSED_PARAM, char **
@@ -12351,8 +12351,17 @@ exportcmd(int argc UNUSED_PARAM, char **
const char *p;
char **aptr;
int flag = argv[0][0] == 'r' ? VREADONLY : VEXPORT;
@ -19,7 +19,7 @@
aptr = argptr;
name = *aptr;
if (name) {
@@ -12353,10 +12362,12 @@ exportcmd(int argc UNUSED_PARAM, char **
@@ -12364,10 +12373,12 @@ exportcmd(int argc UNUSED_PARAM, char **
vp = *findvar(hashvar(name), name);
if (vp) {
vp->flags |= flag;

View File

@ -1,6 +1,6 @@
--- a/include/applets.h
+++ b/include/applets.h
@@ -282,6 +282,7 @@ IF_MT(APPLET(mt, _BB_DIR_BIN, _BB_SUID_D
@@ -278,6 +278,7 @@ IF_MT(APPLET(mt, _BB_DIR_BIN, _BB_SUID_D
IF_MV(APPLET(mv, _BB_DIR_BIN, _BB_SUID_DROP))
IF_NAMEIF(APPLET(nameif, _BB_DIR_SBIN, _BB_SUID_DROP))
IF_NC(APPLET(nc, _BB_DIR_USR_BIN, _BB_SUID_DROP))
@ -10,7 +10,7 @@
IF_NMETER(APPLET(nmeter, _BB_DIR_USR_BIN, _BB_SUID_DROP))
--- a/include/usage.h
+++ b/include/usage.h
@@ -3166,6 +3166,9 @@
@@ -3101,6 +3101,9 @@
#endif
@ -22,7 +22,7 @@
#define netstat_full_usage "\n\n" \
--- a/networking/Config.in
+++ b/networking/Config.in
@@ -628,6 +628,12 @@ config NC
@@ -617,6 +617,12 @@ config NC
A simple Unix utility which reads and writes data across network
connections.
@ -44,7 +44,7 @@
+lib-$(CONFIG_NETMSG) += netmsg.o
lib-$(CONFIG_NETSTAT) += netstat.o
lib-$(CONFIG_NSLOOKUP) += nslookup.o
lib-$(CONFIG_NTPD) += ntpd.o
lib-$(CONFIG_PING) += ping.o
--- /dev/null
+++ b/networking/netmsg.c
@@ -0,0 +1,63 @@

View File

@ -3,7 +3,7 @@
--- a/networking/httpd.c
+++ b/networking/httpd.c
@@ -1716,21 +1716,32 @@ static int check_user_passwd(const char
@@ -1699,21 +1699,32 @@ static int check_user_passwd(const char
if (ENABLE_FEATURE_HTTPD_AUTH_MD5) {
char *md5_passwd;

View File

@ -1,6 +1,6 @@
--- a/include/applets.h
+++ b/include/applets.h
@@ -234,6 +234,7 @@ IF_LN(APPLET_NOEXEC(ln, ln, _BB_DIR_BIN,
@@ -233,6 +233,7 @@ IF_LN(APPLET_NOEXEC(ln, ln, _BB_DIR_BIN,
IF_LOAD_POLICY(APPLET(load_policy, _BB_DIR_USR_SBIN, _BB_SUID_DROP))
IF_LOADFONT(APPLET(loadfont, _BB_DIR_USR_SBIN, _BB_SUID_DROP))
IF_LOADKMAP(APPLET(loadkmap, _BB_DIR_SBIN, _BB_SUID_DROP))
@ -10,7 +10,7 @@
IF_LOGNAME(APPLET_NOFORK(logname, logname, _BB_DIR_USR_BIN, _BB_SUID_DROP, logname))
--- a/include/usage.h
+++ b/include/usage.h
@@ -2357,6 +2357,9 @@
@@ -2325,6 +2325,9 @@
#define loadkmap_example_usage \
"$ loadkmap < /etc/i18n/lang-keymap\n"
@ -22,7 +22,7 @@
#define logger_full_usage "\n\n" \
--- a/miscutils/Config.in
+++ b/miscutils/Config.in
@@ -463,6 +463,11 @@ config FEATURE_HDPARM_HDIO_GETSET_DMA
@@ -456,6 +456,11 @@ config FEATURE_HDPARM_HDIO_GETSET_DMA
help
Enables the 'hdparm -d' option to get/set using_dma flag.
@ -36,7 +36,7 @@
default n
--- a/miscutils/Kbuild
+++ b/miscutils/Kbuild
@@ -27,6 +27,7 @@ lib-$(CONFIG_INOTIFYD) += inotifyd.o
@@ -26,6 +26,7 @@ lib-$(CONFIG_INOTIFYD) += inotifyd.o
lib-$(CONFIG_FEATURE_LAST_SMALL)+= last.o
lib-$(CONFIG_FEATURE_LAST_FANCY)+= last_fancy.o
lib-$(CONFIG_LESS) += less.o

View File

@ -1,6 +1,6 @@
--- a/include/usage.h
+++ b/include/usage.h
@@ -1727,6 +1727,7 @@
@@ -1693,6 +1693,7 @@
IF_FEATURE_HTTPD_BASIC_AUTH(" [-r REALM]") \
" [-h HOME]\n" \
"or httpd -d/-e" IF_FEATURE_HTTPD_AUTH_MD5("/-m") " STRING"
@ -8,18 +8,18 @@
#define httpd_full_usage "\n\n" \
"Listen for incoming HTTP requests\n" \
"\nOptions:" \
@@ -1744,6 +1745,8 @@
@@ -1710,6 +1711,8 @@
"\n -m STRING MD5 crypt STRING") \
"\n -e STRING HTML encode STRING" \
"\n -d STRING URL decode STRING" \
+ "\n -R PATH Redirect target path" \
+ "\n -H HOST Redirect target host" \
+ "\n -R PATH Redirect target path" \
+ "\n -H HOST Redirect target host" \
#define hwclock_trivial_usage \
IF_FEATURE_HWCLOCK_LONG_OPTIONS( \
--- a/networking/httpd.c
+++ b/networking/httpd.c
@@ -250,6 +250,8 @@ struct globals {
@@ -248,6 +248,8 @@ struct globals {
const char *found_mime_type;
const char *found_moved_temporarily;
@ -28,7 +28,7 @@
Htaccess_IP *ip_a_d; /* config allow/deny lines */
IF_FEATURE_HTTPD_BASIC_AUTH(const char *g_realm;)
@@ -296,6 +298,8 @@ struct globals {
@@ -294,6 +296,8 @@ struct globals {
#define index_page (G.index_page )
#define found_mime_type (G.found_mime_type )
#define found_moved_temporarily (G.found_moved_temporarily)
@ -37,7 +37,7 @@
#define last_mod (G.last_mod )
#define ip_a_d (G.ip_a_d )
#define g_realm (G.g_realm )
@@ -997,8 +1001,11 @@ static void send_headers(int responseNum
@@ -993,8 +997,11 @@ static void send_headers(int responseNum
}
#endif
if (responseNum == HTTP_MOVED_TEMPORARILY) {
@ -50,7 +50,7 @@
(g_query ? "?" : ""),
(g_query ? g_query : ""));
}
@@ -1941,8 +1948,12 @@ static void handle_incoming_and_exit(con
@@ -1924,8 +1931,12 @@ static void handle_incoming_and_exit(con
} while (*++tptr);
*++urlp = '\0'; /* terminate after last character */
@ -61,10 +61,10 @@
/* If URL is a directory, add '/' */
- if (urlp[-1] != '/') {
+ if (!redirect_path && (urlp[-1] != '/')) {
if (is_directory(urlcopy + 1, 1, NULL)) {
if (is_directory(urlcopy + 1, 1, &sb)) {
found_moved_temporarily = urlcopy;
}
@@ -2283,7 +2294,9 @@ static void sighup_handler(int sig UNUSE
@@ -2266,7 +2277,9 @@ static void sighup_handler(int sig UNUSE
}
enum {
@ -75,7 +75,7 @@
d_opt_decode_url,
h_opt_home_httpd,
IF_FEATURE_HTTPD_ENCODE_URL_STR(e_opt_encode_url,)
@@ -2332,12 +2345,13 @@ int httpd_main(int argc UNUSED_PARAM, ch
@@ -2315,12 +2328,13 @@ int httpd_main(int argc UNUSED_PARAM, ch
/* We do not "absolutize" path given by -h (home) opt.
* If user gives relative path in -h,
* $SCRIPT_FILENAME will not be set. */

View File

@ -1,6 +1,6 @@
--- a/networking/httpd.c
+++ b/networking/httpd.c
@@ -1254,10 +1254,10 @@ static NOINLINE void cgi_io_loop_and_exi
@@ -1250,10 +1250,10 @@ static NOINLINE void cgi_io_loop_and_exi
if (full_write(STDOUT_FILENO, HTTP_200, sizeof(HTTP_200)-1) != sizeof(HTTP_200)-1)
break;
}

View File

@ -1,6 +1,6 @@
--- a/networking/httpd.c
+++ b/networking/httpd.c
@@ -1827,6 +1827,7 @@ static void handle_incoming_and_exit(con
@@ -1810,6 +1810,7 @@ static void handle_incoming_and_exit(con
char *header_ptr = header_ptr;
Htaccess_Proxy *proxy_entry;
#endif

View File

@ -119,7 +119,7 @@
}
--- a/modutils/Config.in
+++ b/modutils/Config.in
@@ -226,7 +226,7 @@ config FEATURE_MODUTILS_SYMBOLS
@@ -210,7 +210,7 @@ config FEATURE_MODUTILS_SYMBOLS
config DEFAULT_MODULES_DIR
string "Default directory containing modules"
default "/lib/modules"

View File

@ -1,7 +1,7 @@
--- a/util-linux/mount.c
+++ b/util-linux/mount.c
@@ -77,6 +77,10 @@
# include <rpc/pmap_clnt.h>
@@ -69,6 +69,10 @@
#define MS_DIRSYNC 128 // Directory modifications are synchronous
#endif
+#ifndef MS_UNION
@ -11,7 +11,7 @@
#if defined(__dietlibc__)
// 16.12.2006, Sampo Kellomaki (sampo@iki.fi)
@@ -194,6 +198,7 @@ static const int32_t mount_options[] = {
@@ -185,6 +189,7 @@ static const int32_t mount_options[] = {
/* "rslave" */ MS_SLAVE|MS_RECURSIVE,
/* "rprivate" */ MS_SLAVE|MS_RECURSIVE,
/* "runbindable" */ MS_UNBINDABLE|MS_RECURSIVE,
@ -19,7 +19,7 @@
)
// Always understood.
@@ -249,6 +254,7 @@ static const char mount_option_str[] =
@@ -239,6 +244,7 @@ static const char mount_option_str[] =
"rslave\0"
"rprivate\0"
"runbindable\0"

View File

@ -15,7 +15,7 @@
} func;
/* I/O stream */
@@ -1424,7 +1429,8 @@ static void parse_program(char *p)
@@ -1420,7 +1425,8 @@ static void parse_program(char *p)
next_token(TC_FUNCTION);
g_pos++;
f = newfunc(t_string);
@ -25,7 +25,7 @@
f->nargs = 0;
while (next_token(TC_VARIABLE | TC_SEQTERM) & TC_VARIABLE) {
v = findvar(ahash, t_string);
@@ -1433,7 +1439,7 @@ static void parse_program(char *p)
@@ -1429,7 +1435,7 @@ static void parse_program(char *p)
if (next_token(TC_COMMA | TC_SEQTERM) & TC_SEQTERM)
break;
}
@ -34,7 +34,7 @@
chain_group();
clear_array(ahash);
@@ -2446,7 +2452,8 @@ static var *evaluate(node *op, var *res)
@@ -2410,7 +2416,8 @@ static var *evaluate(node *op, var *res)
break;
case XC( OC_FUNC ):
@ -43,8 +43,8 @@
+ !op->r.f->x.body.first)
syntax_error(EMSG_UNDEF_FUNC);
X.v = R.v = nvalloc(op->r.f->nargs + 1);
@@ -2463,7 +2470,10 @@ static var *evaluate(node *op, var *res)
X.v = R.v = nvalloc(op->r.f->nargs+1);
@@ -2427,7 +2434,10 @@ static var *evaluate(node *op, var *res)
fnargs = X.v;
L.s = g_progname;
@ -56,7 +56,7 @@
g_progname = L.s;
nvfree(fnargs);
@@ -2829,6 +2839,143 @@ static rstream *next_input_file(void)
@@ -2790,6 +2800,143 @@ static rstream *next_input_file(void)
#undef files_happen
}
@ -200,7 +200,7 @@
int awk_main(int argc, char **argv) MAIN_EXTERNALLY_VISIBLE;
int awk_main(int argc, char **argv)
{
@@ -2894,6 +3041,9 @@ int awk_main(int argc, char **argv)
@@ -2855,6 +3002,9 @@ int awk_main(int argc, char **argv)
*s1 = '=';
}
}

View File

@ -1,6 +1,6 @@
--- a/networking/telnetd.c
+++ b/networking/telnetd.c
@@ -308,6 +308,7 @@ make_new_session(
@@ -306,6 +306,7 @@ make_new_session(
/* Restore default signal handling ASAP */
bb_signals((1 << SIGCHLD) + (1 << SIGPIPE), SIG_DFL);

View File

@ -126,10 +126,8 @@ define Build/Prepare
$(INSTALL_DIR) $(PKG_BUILD_DIR)/src/mei/
$(CP) ./src/* $(PKG_BUILD_DIR)/src/mei/
$(Build/Patch)
ifeq ($(CONFIG_IFXMIPS_DSL_FIRMWARE),)
$(TAR) -C $(PKG_BUILD_DIR) -xzf $(DL_DIR)/$(FW_BASE_NAME)_a-$(FW_A_VER).tar.gz
$(TAR) -C $(PKG_BUILD_DIR) -xzf $(DL_DIR)/$(FW_BASE_NAME)_b-$(FW_B_VER).tar.gz
endif
endef
define Build/Configure

View File

@ -156,25 +156,6 @@ endef
$(eval $(call KernelPackage,ata-magicbox-cf))
define KernelPackage/ata-pdc202xx-old
SUBMENU:=$(BLOCK_MENU)
TITLE:=Older Promise PATA controller support
DEPENDS:=kmod-ata-core
KCONFIG:= \
CONFIG_ATA_SFF=y \
CONFIG_PATA_PDC_OLD
FILES:=$(LINUX_DIR)/drivers/ata/pata_pdc202xx_old.$(LINUX_KMOD_SUFFIX)
AUTOLOAD:=$(call AutoLoad,41,pata_pdc202xx_old,1)
endef
define KernelPackage/ata-pdc202xx-old/description
This option enables support for the Promise 20246, 20262, 20263,
20265 and 20267 adapters.
endef
$(eval $(call KernelPackage,ata-pdc202xx-old))
define KernelPackage/ata-piix
$(call KernelPackage/ata/Depends,)
TITLE:=Intel PIIX PATA/SATA support

View File

@ -802,7 +802,7 @@ define KernelPackage/cs5535-gpio
DEPENDS:=@TARGET_x86
KCONFIG:=CONFIG_CS5535_GPIO
FILES:=$(LINUX_DIR)/drivers/char/cs5535_gpio.$(LINUX_KMOD_SUFFIX)
AUTOLOAD:=$(call AutoLoad,50,cs5535_gpio)
AUTOLOAD:=$(call AutoLoad,90,cs5535_gpio)
endef
define KernelPackage/cs5535-gpio/description
@ -875,34 +875,3 @@ define KernelPackage/rfkill/description
endef
$(eval $(call KernelPackage,rfkill))
define KernelPackage/geodewdt
SUBMENU:=$(OTHER_MENU)
TITLE:=Geode/LX Watchdog timer
DEPENDS:=@TARGET_x86 @LINUX_2_6
KCONFIG:=CONFIG_GEODE_WDT
FILES:=$(LINUX_DIR)/drivers/$(WATCHDOG_DIR)/geodewdt.$(LINUX_KMOD_SUFFIX)
AUTOLOAD:=$(call AutoLoad,50,geodewdt)
endef
define KernelPackage/geodewdt/description
Kernel module for Geode watchdog timer.
endef
$(eval $(call KernelPackage,geodewdt))
define KernelPackage/pc8736x-gpio
SUBMENU:=$(OTHER_MENU)
TITLE:=PC8736x GPIO support
DEPENDS:=@TARGET_x86
KCONFIG:=CONFIG_PC8736x_GPIO
FILES:=$(LINUX_DIR)/drivers/char/pc8736x_gpio.$(LINUX_KMOD_SUFFIX)
AUTOLOAD:=$(call AutoLoad,40,pc8736x_gpio)
endef
define KernelPackage/pc8736x-gpio/description
Kernel module for PC8736x GPIO
endef
$(eval $(call KernelPackage,pc8736x-gpio))

View File

@ -10,12 +10,12 @@ include $(INCLUDE_DIR)/kernel.mk
PKG_NAME:=mac80211
PKG_VERSION:=2010-04-13
PKG_RELEASE:=1
PKG_VERSION:=2010-03-24
PKG_RELEASE:=5
PKG_SOURCE_URL:=http://mirror2.openwrt.org/sources
# http://www.orbit-lab.org/kernel/compat-wireless-2.6/2010/11 \
# http://wireless.kernel.org/download/compat-wireless-2.6
PKG_MD5SUM:=d70715219e37214463c0e08974db80c1
PKG_MD5SUM:=73357c52b5d6888ea3228b2ca8aa5eca
PKG_SOURCE:=compat-wireless-$(PKG_VERSION).tar.bz2
PKG_BUILD_DIR:=$(KERNEL_BUILD_DIR)/compat-wireless-$(PKG_VERSION)

View File

@ -1,6 +1,6 @@
--- a/config.mk
+++ b/config.mk
@@ -256,8 +256,8 @@ endif
@@ -269,8 +269,8 @@ endif
CONFIG_P54_PCI=m

View File

@ -9,7 +9,7 @@
ifeq ($(CONFIG_MAC80211),y)
$(error "ERROR: you have MAC80211 compiled into the kernel, CONFIG_MAC80211=y, as such you cannot replace its mac80211 driver. You need this set to CONFIG_MAC80211=m. If you are using Fedora upgrade your kernel as later version should this set as modular. For further information on Fedora see https://bugzilla.redhat.com/show_bug.cgi?id=470143. If you are using your own kernel recompile it and make mac80211 modular")
@@ -481,8 +481,8 @@ endif
@@ -492,8 +492,8 @@ endif
# We need the backported rfkill module on kernel < 2.6.31.
# In more recent kernel versions use the in kernel rfkill module.
ifdef CONFIG_COMPAT_KERNEL_31

View File

@ -1,6 +1,6 @@
--- a/config.mk
+++ b/config.mk
@@ -286,10 +286,10 @@ endif
@@ -299,10 +299,10 @@ endif
CONFIG_MWL8K=m
# Ethernet drivers go here
@ -15,7 +15,7 @@
CONFIG_HERMES=m
CONFIG_HERMES_CACHE_FW_ON_INIT=y
@@ -342,10 +342,10 @@ CONFIG_USB_NET_COMPAT_RNDIS_HOST=n
@@ -355,10 +355,10 @@ CONFIG_USB_NET_COMPAT_RNDIS_HOST=n
CONFIG_USB_NET_COMPAT_RNDIS_WLAN=n
CONFIG_USB_NET_COMPAT_CDCETHER=n
else

View File

@ -9,7 +9,7 @@
CONFIG_SSB=m
else
include $(KLIB_BUILD)/.config
@@ -181,7 +181,7 @@ CONFIG_B43=m
@@ -194,7 +194,7 @@ CONFIG_B43=m
CONFIG_B43_HWRNG=y
CONFIG_B43_PCI_AUTOSELECT=y
ifneq ($(CONFIG_PCMCIA),)
@ -18,7 +18,7 @@
endif
CONFIG_B43_LEDS=y
CONFIG_B43_PHY_LP=y
@@ -233,7 +233,7 @@ CONFIG_SSB_BLOCKIO=y
@@ -246,7 +246,7 @@ CONFIG_SSB_BLOCKIO=y
CONFIG_SSB_PCIHOST=y
CONFIG_SSB_B43_PCI_BRIDGE=y
ifneq ($(CONFIG_PCMCIA),)

View File

@ -1,6 +1,6 @@
--- a/config.mk
+++ b/config.mk
@@ -396,8 +396,8 @@ endif # end of SPI driver list
@@ -407,8 +407,8 @@ endif # end of SPI driver list
ifneq ($(CONFIG_MMC),)

View File

@ -1,6 +1,6 @@
--- a/config.mk
+++ b/config.mk
@@ -185,7 +185,7 @@ ifneq ($(CONFIG_PCMCIA),)
@@ -198,7 +198,7 @@ ifneq ($(CONFIG_PCMCIA),)
endif
CONFIG_B43_LEDS=y
CONFIG_B43_PHY_LP=y

View File

@ -0,0 +1,33 @@
commit b7d48ccc687c44213121b1b565dccdc4488f5d9a
Author: Pavel Roskin <proski@gnu.org>
Date: Wed Mar 24 17:23:37 2010 -0400
compat: add compat-2.6.35.h and IW_HANDLER
Signed-off-by: Pavel Roskin <proski@gnu.org>
--- /dev/null
+++ b/include/linux/compat-2.6.35.h
@@ -0,0 +1,13 @@
+#ifndef LINUX_26_35_COMPAT_H
+#define LINUX_26_35_COMPAT_H
+
+#include <linux/version.h>
+
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(2,6,35))
+
+#define IW_HANDLER(id, func) \
+ [IW_IOCTL_IDX(id)] = func
+
+#endif /* (LINUX_VERSION_CODE < KERNEL_VERSION(2,6,35)) */
+
+#endif /* LINUX_26_35_COMPAT_H */
--- a/include/linux/compat-2.6.h
+++ b/include/linux/compat-2.6.h
@@ -27,5 +27,6 @@
#include <linux/compat-2.6.32.h>
#include <linux/compat-2.6.33.h>
#include <linux/compat-2.6.34.h>
+#include <linux/compat-2.6.35.h>
#endif /* LINUX_26_COMPAT_H */

View File

@ -1,6 +1,6 @@
--- a/config.mk
+++ b/config.mk
@@ -248,12 +248,12 @@ CONFIG_RTL8180=m
@@ -276,12 +276,12 @@ CONFIG_RTL8180=m
CONFIG_ADM8211=m
@ -15,7 +15,7 @@
# CONFIG_RT2800PCI_RT30XX=y
# CONFIG_RT2800PCI_RT35XX=y
# CONFIG_RT2800PCI_SOC=y
@@ -355,7 +355,7 @@ CONFIG_RT2800USB=m
@@ -381,7 +381,7 @@ CONFIG_RT2800USB=m
# CONFIG_RT2800USB_RT35XX=y
# CONFIG_RT2800USB_UNKNOWN=y
endif

View File

@ -0,0 +1,45 @@
From 181ce6f71d907f42ab73376ce154015a835a6d8a Mon Sep 17 00:00:00 2001
From: Javier Cardona <javier@cozybit.com>
Date: Mon, 29 Mar 2010 11:00:20 -0700
Subject: [PATCH] mac80211: Handle mesh action frames in ieee80211_rx_h_action
This fixes the problem introduced in commit
8404080568613d93ad7cf0a16dfb68 which broke mesh peer link establishment.
changes:
v2 Added missing break (Johannes)
v3 Broke original patch into two (Johannes)
Signed-off-by: Javier Cardona <javier@cozybit.com>
Signed-off-by: Hauke Mehrtens <hauke@hauke-m.de>
---
net/mac80211/mesh.c | 3 ---
net/mac80211/rx.c | 5 +++++
2 files changed, 5 insertions(+), 3 deletions(-)
--- a/net/mac80211/mesh.c
+++ b/net/mac80211/mesh.c
@@ -749,9 +749,6 @@ ieee80211_mesh_rx_mgmt(struct ieee80211_
switch (fc & IEEE80211_FCTL_STYPE) {
case IEEE80211_STYPE_ACTION:
- if (skb->len < IEEE80211_MIN_ACTION_SIZE)
- return RX_DROP_MONITOR;
- /* fall through */
case IEEE80211_STYPE_PROBE_RESP:
case IEEE80211_STYPE_BEACON:
skb_queue_tail(&ifmsh->skb_queue, skb);
--- a/net/mac80211/rx.c
+++ b/net/mac80211/rx.c
@@ -1964,6 +1964,11 @@ ieee80211_rx_h_action(struct ieee80211_r
goto handled;
}
break;
+ case MESH_PLINK_CATEGORY:
+ case MESH_PATH_SEL_CATEGORY:
+ if (ieee80211_vif_is_mesh(&sdata->vif))
+ return ieee80211_mesh_rx_mgmt(sdata, rx->skb);
+ break;
}
/*

View File

@ -1,14 +1,14 @@
--- a/drivers/net/wireless/ath/ath9k/hw.c
+++ b/drivers/net/wireless/ath/ath9k/hw.c
@@ -16,6 +16,7 @@
@@ -15,6 +15,7 @@
*/
#include <linux/io.h>
#include <linux/slab.h>
+#include <linux/etherdevice.h>
#include <asm/unaligned.h>
#include "hw.h"
@@ -431,8 +432,16 @@ static int ath9k_hw_init_macaddr(struct
@@ -441,8 +442,16 @@ static int ath9k_hw_init_macaddr(struct
common->macaddr[2 * i] = eeval >> 8;
common->macaddr[2 * i + 1] = eeval & 0xff;
}

View File

@ -1,6 +1,6 @@
--- a/drivers/net/wireless/ath/regd.c
+++ b/drivers/net/wireless/ath/regd.c
@@ -18,6 +18,9 @@
@@ -19,6 +19,9 @@
#include <net/cfg80211.h>
#include <net/mac80211.h>
#include "regd.h"

View File

@ -8,7 +8,7 @@
#include "ath9k.h"
static DEFINE_PCI_DEVICE_TABLE(ath_pci_id_table) = {
@@ -53,21 +54,36 @@ static void ath_pci_read_cachesize(struc
@@ -52,21 +53,36 @@ static void ath_pci_read_cachesize(struc
static bool ath_pci_eeprom_read(struct ath_common *common, u32 off, u16 *data)
{

View File

@ -1,3 +1,17 @@
--- a/drivers/net/wireless/ath/ath9k/hw.c
+++ b/drivers/net/wireless/ath/ath9k/hw.c
@@ -385,11 +385,8 @@ static void ath9k_hw_init_defaults(struc
ah->hw_version.magic = AR5416_MAGIC;
ah->hw_version.subvendorid = 0;
- ah->ah_flags = 0;
if (ah->hw_version.devid == AR5416_AR9100_DEVID)
ah->hw_version.macVersion = AR_SREV_VERSION_9100;
- if (!AR_SREV_9100(ah))
- ah->ah_flags = AH_USE_EEPROM;
ah->atim_window = 0;
ah->sta_id1_defaults = AR_STA_ID1_CRPT_MIC_ENABLE;
--- a/drivers/net/wireless/ath/ath9k/main.c
+++ b/drivers/net/wireless/ath/ath9k/main.c
@@ -15,6 +15,7 @@
@ -10,7 +24,7 @@
--- a/drivers/net/wireless/ath/ath9k/init.c
+++ b/drivers/net/wireless/ath/ath9k/init.c
@@ -542,6 +542,7 @@ static int ath9k_init_softc(u16 devid, s
@@ -531,6 +531,7 @@ static int ath9k_init_softc(u16 devid, s
{
struct ath_hw *ah = NULL;
struct ath_common *common;
@ -18,7 +32,7 @@
int ret = 0, i;
int csz = 0;
@@ -553,6 +554,10 @@ static int ath9k_init_softc(u16 devid, s
@@ -542,6 +543,10 @@ static int ath9k_init_softc(u16 devid, s
ah->hw_version.subsysid = subsysid;
sc->sc_ah = ah;
@ -29,16 +43,3 @@
common = ath9k_hw_common(ah);
common->ops = &ath9k_common_ops;
common->bus_ops = bus_ops;
--- a/drivers/net/wireless/ath/ath9k/hw.c
+++ b/drivers/net/wireless/ath/ath9k/hw.c
@@ -404,10 +404,6 @@ static void ath9k_hw_init_defaults(struc
ah->hw_version.magic = AR5416_MAGIC;
ah->hw_version.subvendorid = 0;
- ah->ah_flags = 0;
- if (!AR_SREV_9100(ah))
- ah->ah_flags = AH_USE_EEPROM;
-
ah->atim_window = 0;
ah->sta_id1_defaults = AR_STA_ID1_CRPT_MIC_ENABLE;
ah->beacon_interval = 100;

View File

@ -1,17 +1,17 @@
--- a/drivers/net/wireless/ath/ath9k/hw.c
+++ b/drivers/net/wireless/ath/ath9k/hw.c
@@ -17,8 +17,10 @@
@@ -16,8 +16,10 @@
#include <linux/io.h>
#include <linux/slab.h>
#include <linux/etherdevice.h>
+#include <linux/ath9k_platform.h>
#include <asm/unaligned.h>
+#include "ath9k.h"
#include "hw.h"
#include "hw-ops.h"
#include "rc.h"
@@ -416,18 +418,23 @@ static void ath9k_hw_init_defaults(struc
#include "initvals.h"
@@ -428,17 +430,23 @@ static int ath9k_hw_rf_claim(struct ath_
static int ath9k_hw_init_macaddr(struct ath_hw *ah)
{
struct ath_common *common = ath9k_hw_common(ah);
@ -20,11 +20,10 @@
u32 sum;
int i;
u16 eeval;
u32 EEP_MAC[] = { EEP_MAC_LSW, EEP_MAC_MID, EEP_MAC_MSW };
sum = 0;
- for (i = 0; i < 3; i++) {
- eeval = ah->eep_ops->get_eeprom(ah, EEP_MAC[i]);
- eeval = ah->eep_ops->get_eeprom(ah, AR_EEPROM_MAC(i));
- sum += eeval;
- common->macaddr[2 * i] = eeval >> 8;
- common->macaddr[2 * i + 1] = eeval & 0xff;
@ -33,11 +32,12 @@
+ memcpy(common->macaddr, pdata->macaddr, ETH_ALEN);
+ else
+ for (i = 0; i < 3; i++) {
+ eeval = ah->eep_ops->get_eeprom(ah, EEP_MAC[i]);
+ eeval = ah->eep_ops->get_eeprom(ah, AR_EEPROM_MAC(i));
+ sum += eeval;
+ common->macaddr[2 * i] = eeval >> 8;
+ common->macaddr[2 * i + 1] = eeval & 0xff;
+ }
+
if (!is_valid_ether_addr(common->macaddr)) {
ath_print(common, ATH_DBG_EEPROM,
"eeprom contains invalid mac address: %pM\n",

View File

@ -1,6 +1,6 @@
--- a/drivers/net/wireless/ath/ath9k/hw.c
+++ b/drivers/net/wireless/ath/ath9k/hw.c
@@ -1298,7 +1298,7 @@ int ath9k_hw_reset(struct ath_hw *ah, st
@@ -2097,7 +2097,7 @@ int ath9k_hw_reset(struct ath_hw *ah, st
if (ah->config.rx_intr_mitigation) {
REG_RMW_FIELD(ah, AR_RIMT, AR_RIMT_LAST, 500);
@ -8,4 +8,4 @@
+ REG_RMW_FIELD(ah, AR_RIMT, AR_RIMT_FIRST, 500);
}
if (ah->config.tx_intr_mitigation) {
ath9k_hw_init_bb(ah, chan);

View File

@ -1,14 +1,14 @@
--- a/drivers/net/wireless/ath/ath9k/init.c
+++ b/drivers/net/wireless/ath/ath9k/init.c
@@ -16,6 +16,7 @@
#include <linux/slab.h>
@@ -14,6 +14,7 @@
* OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/
+#include "linux/ath9k_platform.h"
#include "ath9k.h"
static char *dev_info = "ath9k";
@@ -557,6 +558,8 @@ static int ath9k_init_softc(u16 devid, s
@@ -546,6 +547,8 @@ static int ath9k_init_softc(u16 devid, s
pdata = (struct ath9k_platform_data *) sc->dev->platform_data;
if (!pdata)
ah->ah_flags |= AH_USE_EEPROM;
@ -17,7 +17,7 @@
common = ath9k_hw_common(ah);
common->ops = &ath9k_common_ops;
@@ -679,6 +682,24 @@ void ath9k_set_hw_capab(struct ath_softc
@@ -671,6 +674,24 @@ void ath9k_set_hw_capab(struct ath_softc
SET_IEEE80211_PERM_ADDR(hw, common->macaddr);
}
@ -42,7 +42,7 @@
int ath9k_init_device(u16 devid, struct ath_softc *sc, u16 subsysid,
const struct ath_bus_ops *bus_ops)
{
@@ -697,6 +718,9 @@ int ath9k_init_device(u16 devid, struct
@@ -689,6 +710,9 @@ int ath9k_init_device(u16 devid, struct
common = ath9k_hw_common(ah);
ath9k_set_hw_capab(sc, hw);
@ -54,15 +54,15 @@
ath9k_reg_notifier);
--- a/drivers/net/wireless/ath/ath9k/ath9k.h
+++ b/drivers/net/wireless/ath/ath9k/ath9k.h
@@ -517,6 +517,8 @@ struct ath_softc {
int beacon_interval;
+ bool quirk_wndr3700;
@@ -511,6 +511,8 @@ struct ath_softc {
struct ath_beacon_config cur_beacon_conf;
struct delayed_work tx_complete_work;
struct ath_btcoex btcoex;
+
#ifdef CONFIG_ATH9K_DEBUGFS
struct ath9k_debug debug;
#endif
+ unsigned long quirk_wndr3700:1;
};
struct ath_wiphy {
--- a/include/linux/ath9k_platform.h
+++ b/include/linux/ath9k_platform.h
@@ -24,6 +24,8 @@
@ -70,7 +70,7 @@
u16 eeprom_data[ATH9K_PLAT_EEP_MAX_WORDS];
u8 *macaddr;
+
+ bool quirk_wndr3700;
+ unsigned long quirk_wndr3700:1;
};
#endif /* _LINUX_ATH9K_PLATFORM_H */

View File

@ -13,7 +13,7 @@
sc->sc_ah->led_pin = ATH_LED_PIN_DEF;
--- a/drivers/net/wireless/ath/ath9k/ath9k.h
+++ b/drivers/net/wireless/ath/ath9k/ath9k.h
@@ -392,6 +392,7 @@ void ath9k_btcoex_timer_pause(struct ath
@@ -379,6 +379,7 @@ void ath9k_btcoex_timer_pause(struct ath
#define ATH_LED_PIN_DEF 1
#define ATH_LED_PIN_9287 8

View File

@ -1,6 +1,6 @@
--- a/drivers/net/wireless/ath/ath9k/debug.c
+++ b/drivers/net/wireless/ath/ath9k/debug.c
@@ -78,6 +78,90 @@ static const struct file_operations fops
@@ -77,6 +77,90 @@ static const struct file_operations fops
#define DMA_BUF_LEN 1024
@ -91,7 +91,7 @@
static ssize_t read_file_dma(struct file *file, char __user *user_buf,
size_t count, loff_t *ppos)
{
@@ -731,6 +815,16 @@ int ath9k_init_debug(struct ath_hw *ah)
@@ -719,6 +803,16 @@ int ath9k_init_debug(struct ath_hw *ah)
goto err;
#endif
@ -108,7 +108,7 @@
sc->debug.debugfs_dma = debugfs_create_file("dma", S_IRUSR,
sc->debug.debugfs_phy, sc, &fops_dma);
if (!sc->debug.debugfs_dma)
@@ -781,6 +875,8 @@ void ath9k_exit_debug(struct ath_hw *ah)
@@ -769,6 +863,8 @@ void ath9k_exit_debug(struct ath_hw *ah)
struct ath_common *common = ath9k_hw_common(ah);
struct ath_softc *sc = (struct ath_softc *) common->priv;
@ -119,7 +119,7 @@
debugfs_remove(sc->debug.debugfs_wiphy);
--- a/drivers/net/wireless/ath/ath9k/debug.h
+++ b/drivers/net/wireless/ath/ath9k/debug.h
@@ -152,6 +152,8 @@ struct ath_stats {
@@ -148,6 +148,8 @@ struct ath_stats {
};
struct ath9k_debug {

View File

@ -1,6 +1,6 @@
--- a/drivers/net/wireless/ath/ath9k/debug.c
+++ b/drivers/net/wireless/ath/ath9k/debug.c
@@ -795,6 +795,86 @@ static const struct file_operations fops
@@ -783,6 +783,86 @@ static const struct file_operations fops
.owner = THIS_MODULE
};
@ -87,7 +87,7 @@
int ath9k_init_debug(struct ath_hw *ah)
{
struct ath_common *common = ath9k_hw_common(ah);
@@ -864,6 +944,17 @@ int ath9k_init_debug(struct ath_hw *ah)
@@ -852,6 +932,17 @@ int ath9k_init_debug(struct ath_hw *ah)
if (!sc->debug.debugfs_recv)
goto err;
@ -105,7 +105,7 @@
return 0;
err:
ath9k_exit_debug(ah);
@@ -877,6 +968,8 @@ void ath9k_exit_debug(struct ath_hw *ah)
@@ -865,6 +956,8 @@ void ath9k_exit_debug(struct ath_hw *ah)
debugfs_remove(sc->debug.debugfs_tx_chainmask);
debugfs_remove(sc->debug.debugfs_rx_chainmask);
@ -116,7 +116,7 @@
debugfs_remove(sc->debug.debugfs_wiphy);
--- a/drivers/net/wireless/ath/ath9k/debug.h
+++ b/drivers/net/wireless/ath/ath9k/debug.h
@@ -162,6 +162,9 @@ struct ath9k_debug {
@@ -158,6 +158,9 @@ struct ath9k_debug {
struct dentry *debugfs_wiphy;
struct dentry *debugfs_xmit;
struct dentry *debugfs_recv;

View File

@ -1,6 +1,6 @@
--- a/drivers/net/wireless/ath/ath9k/init.c
+++ b/drivers/net/wireless/ath/ath9k/init.c
@@ -663,7 +663,11 @@ void ath9k_set_hw_capab(struct ath_softc
@@ -655,7 +655,11 @@ void ath9k_set_hw_capab(struct ath_softc
hw->sta_data_size = sizeof(struct ath_node);
hw->vif_data_size = sizeof(struct ath_vif);

View File

@ -1,7 +1,7 @@
--- a/drivers/net/wireless/ath/ath9k/hw.c
+++ b/drivers/net/wireless/ath/ath9k/hw.c
@@ -1131,6 +1131,34 @@ static bool ath9k_hw_channel_change(stru
return true;
@@ -1911,6 +1911,34 @@ static void ath9k_enable_rfkill(struct a
REG_SET_BIT(ah, AR_PHY_TEST, RFSILENT_BB);
}
+bool ath9k_hw_check_alive(struct ath_hw *ah)
@ -37,7 +37,7 @@
{
--- a/drivers/net/wireless/ath/ath9k/hw.h
+++ b/drivers/net/wireless/ath/ath9k/hw.h
@@ -846,6 +846,7 @@ void ath9k_hw_set11nmac2040(struct ath_h
@@ -679,6 +679,7 @@ void ath9k_hw_set11nmac2040(struct ath_h
void ath9k_hw_beaconinit(struct ath_hw *ah, u32 next_beacon, u32 beacon_period);
void ath9k_hw_set_sta_beacon_timers(struct ath_hw *ah,
const struct ath9k_beacon_state *bs);
@ -47,7 +47,7 @@
--- a/drivers/net/wireless/ath/ath9k/main.c
+++ b/drivers/net/wireless/ath/ath9k/main.c
@@ -406,7 +406,8 @@ void ath9k_tasklet(unsigned long data)
@@ -405,7 +405,8 @@ void ath9k_tasklet(unsigned long data)
ath9k_ps_wakeup(sc);

View File

@ -1,6 +1,6 @@
--- a/drivers/net/wireless/rt2x00/rt2x00pci.c
+++ b/drivers/net/wireless/rt2x00/rt2x00pci.c
@@ -224,6 +224,7 @@ void rt2x00pci_uninitialize(struct rt2x0
@@ -223,6 +223,7 @@ void rt2x00pci_uninitialize(struct rt2x0
}
EXPORT_SYMBOL_GPL(rt2x00pci_uninitialize);
@ -8,7 +8,7 @@
/*
* PCI driver handlers.
*/
@@ -398,6 +399,7 @@ int rt2x00pci_resume(struct pci_dev *pci
@@ -397,6 +398,7 @@ int rt2x00pci_resume(struct pci_dev *pci
}
EXPORT_SYMBOL_GPL(rt2x00pci_resume);
#endif /* CONFIG_PM */

View File

@ -1,6 +1,6 @@
--- a/drivers/net/wireless/rt2x00/rt2x00pci.c
+++ b/drivers/net/wireless/rt2x00/rt2x00pci.c
@@ -214,7 +214,7 @@ void rt2x00pci_uninitialize(struct rt2x0
@@ -213,7 +213,7 @@ void rt2x00pci_uninitialize(struct rt2x0
/*
* Free irq line.
*/

View File

@ -1,29 +1,59 @@
From f18d4463d092162f34a8bd226505627ceeac3e8a Mon Sep 17 00:00:00 2001
From: Luis Correia <luis.f.correia@gmail.com>
Date: Sat, 3 Apr 2010 12:49:53 +0100
Subject: [PATCH] rt2x00: remove MCU requests for SoC platforms
The ralink SoC platforms do not have an MCU.
Signed-off-by: Luis Correia <luis.f.correia@gmail.com>
Acked-by: Ivo van Doorn <IvDoorn@gmail.com>
Signed-off-by: Gertjan van Wingerde <gwingerde@gmail.com>
---
drivers/net/wireless/rt2x00/rt2800pci.c | 6 ++++++
1 files changed, 6 insertions(+), 0 deletions(-)
--- a/drivers/net/wireless/rt2x00/rt2800pci.c
+++ b/drivers/net/wireless/rt2x00/rt2800pci.c
@@ -66,6 +66,12 @@ static void rt2800pci_mcu_status(struct
if (rt2x00_is_soc(rt2x00dev))
--- a/drivers/net/wireless/rt2x00/rt2800lib.c
+++ b/drivers/net/wireless/rt2x00/rt2800lib.c
@@ -221,9 +221,9 @@ void rt2800_mcu_request(struct rt2x00_de
u32 reg;
/*
- * SOC devices don't support MCU requests.
+ * some devices don't support MCU requests.
*/
- if (rt2x00_is_soc(rt2x00dev))
+ if (!test_bit(DRIVER_REQUIRE_MCU, &rt2x00dev->flags))
return;
mutex_lock(&rt2x00dev->csr_mutex);
--- a/drivers/net/wireless/rt2x00/rt2x00.h
+++ b/drivers/net/wireless/rt2x00/rt2x00.h
@@ -631,6 +631,7 @@ enum rt2x00_flags {
* Driver requirements
*/
DRIVER_REQUIRE_FIRMWARE,
+ DRIVER_REQUIRE_MCU,
DRIVER_REQUIRE_BEACON_GUARD,
DRIVER_REQUIRE_ATIM_QUEUE,
DRIVER_REQUIRE_DMA,

View File

@ -9,9 +9,8 @@ include $(TOPDIR)/rules.mk
include $(INCLUDE_DIR)/kernel.mk
PKG_NAME:=u-boot
PKG_VERSION:=2010.03
PKG_MD5SUM:=2bf5ebf497dddc52440b1ea386cc1332
PKG_VERSION:=2009.11.1
PKG_MD5SUM:=6086421c9e2f3a0d0dbc5f706b551dbc
PKG_RELEASE:=1
PKG_BUILD_DIR:=$(KERNEL_BUILD_DIR)/$(PKG_NAME)-$(PKG_VERSION)

View File

@ -7,10 +7,9 @@ $ make -s V=1
[CC] tools/img2srec.c
[CC] tools/bmp_logo.c
[CC] examples/hello_world.c
--- a/config.mk
+++ b/config.mk
@@ -234,17 +234,42 @@ export TEXT_BASE PLATFORM_CPPFLAGS PLATF
@@ -206,17 +206,42 @@ export TEXT_BASE PLATFORM_CPPFLAGS PLATF
#########################################################################

View File

@ -1,6 +1,6 @@
--- a/MAKEALL
+++ b/MAKEALL
@@ -730,6 +730,12 @@ LIST_arm=" \
@@ -709,6 +709,12 @@ LIST_arm=" \
## MIPS Systems (default = big endian)
#########################################################################
@ -13,7 +13,7 @@
LIST_mips4kc=" \
incaip \
qemu_mips \
@@ -761,6 +767,7 @@ LIST_au1xx0=" \
@@ -740,6 +746,7 @@ LIST_au1xx0=" \
"
LIST_mips=" \
@ -23,7 +23,7 @@
${LIST_au1xx0} \
--- a/Makefile
+++ b/Makefile
@@ -447,7 +447,7 @@ $(obj)include/autoconf.mk: $(obj)include
@@ -474,7 +474,7 @@ $(obj)include/autoconf.mk: $(obj)include
set -e ; \
: Extract the config macros ; \
$(CPP) $(CFLAGS) -DDO_DEPS_ONLY -dM include/common.h | \
@ -32,7 +32,7 @@
mv $@.tmp $@
#########################################################################
@@ -3370,7 +3370,7 @@ incaip_config: unconfig
@@ -3354,7 +3354,7 @@ incaip_config: unconfig
{ echo "#define CPU_CLOCK_RATE 150000000" >>$(obj)include/config.h ; \
$(XECHO) "... with 150MHz system clock" ; \
}
@ -41,7 +41,7 @@
tb0229_config: unconfig
@$(MKCONFIG) $(@:_config=) mips mips tb0229
@@ -3411,6 +3411,50 @@ vct_platinumavc_onenand_small_config: un
@@ -3395,6 +3395,50 @@ vct_platinumavc_onenand_small_config: un
@$(MKCONFIG) -a vct mips mips vct micronas
#########################################################################
@ -92,16 +92,6 @@
## MIPS32 AU1X00
#########################################################################
--- a/drivers/net/Makefile
+++ b/drivers/net/Makefile
@@ -43,6 +43,7 @@ COBJS-$(CONFIG_FEC_MXC) += fec_mxc.o
COBJS-$(CONFIG_FSLDMAFEC) += fsl_mcdmafec.o mcfmii.o
COBJS-$(CONFIG_FTMAC100) += ftmac100.o
COBJS-$(CONFIG_GRETH) += greth.o
+COBJS-$(CONFIG_IFX_ETOP) += ifx_etop.o
COBJS-$(CONFIG_INCA_IP_SWITCH) += inca-ip_sw.o
COBJS-$(CONFIG_KIRKWOOD_EGIGA) += kirkwood_egiga.o
COBJS-$(CONFIG_DRIVER_KS8695ETH) += ks8695eth.o
--- a/drivers/serial/Makefile
+++ b/drivers/serial/Makefile
@@ -28,6 +28,7 @@ LIB := $(obj)libserial.a
@ -112,17 +102,27 @@
COBJS-$(CONFIG_MCFUART) += mcfuart.o
COBJS-$(CONFIG_NS9750_UART) += ns9750_serial.o
COBJS-$(CONFIG_SYS_NS16550) += ns16550.o
--- a/drivers/net/Makefile
+++ b/drivers/net/Makefile
@@ -41,6 +41,7 @@ COBJS-$(CONFIG_FEC_MXC) += fec_mxc.o
COBJS-$(CONFIG_FSLDMAFEC) += fsl_mcdmafec.o mcfmii.o
COBJS-$(CONFIG_FTMAC100) += ftmac100.o
COBJS-$(CONFIG_GRETH) += greth.o
+COBJS-$(CONFIG_IFX_ETOP) += ifx_etop.o
COBJS-$(CONFIG_INCA_IP_SWITCH) += inca-ip_sw.o
COBJS-$(CONFIG_KIRKWOOD_EGIGA) += kirkwood_egiga.o
COBJS-$(CONFIG_DRIVER_KS8695ETH) += ks8695eth.o
--- a/include/netdev.h
+++ b/include/netdev.h
@@ -57,6 +57,7 @@ int fecmxc_initialize (bd_t *bis);
@@ -55,6 +55,7 @@ int fecmxc_initialize (bd_t *bis);
int ftmac100_initialize(bd_t *bits);
int greth_initialize(bd_t *bis);
void gt6426x_eth_initialize(bd_t *bis);
+int ifx_etop_initialize(bd_t *bis);
int inca_switch_initialize(bd_t *bis);
int kirkwood_egiga_initialize(bd_t *bis);
int lan91c96_initialize(u8 dev_num, int base_addr);
@@ -85,6 +86,7 @@ int uec_standard_init(bd_t *bis);
int macb_eth_initialize(int id, void *regs, unsigned int phy_addr);
@@ -82,6 +83,7 @@ int uec_standard_init(bd_t *bis);
int uli526x_initialize(bd_t *bis);
int sh_eth_initialize(bd_t *bis);
int dm9000_initialize(bd_t *bis);

View File

@ -1,5 +1,7 @@
--- a/common/env_common.c
+++ b/common/env_common.c
Index: u-boot-2009.11.1/common/env_common.c
===================================================================
--- u-boot-2009.11.1.orig/common/env_common.c 2010-01-25 09:35:12.000000000 +0100
+++ u-boot-2009.11.1/common/env_common.c 2010-03-29 13:20:50.000000000 +0200
@@ -26,6 +26,7 @@
#include <common.h>
@ -8,8 +10,10 @@
#include <environment.h>
#include <linux/stddef.h>
#include <malloc.h>
--- a/common/env_embedded.c
+++ b/common/env_embedded.c
Index: u-boot-2009.11.1/common/env_embedded.c
===================================================================
--- u-boot-2009.11.1.orig/common/env_embedded.c 2010-03-29 13:22:19.000000000 +0200
+++ u-boot-2009.11.1/common/env_embedded.c 2010-03-29 13:22:29.000000000 +0200
@@ -27,6 +27,7 @@
#define __ASM_STUB_PROCESSOR_H__ /* don't include asm/processor. */
#include <config.h>

File diff suppressed because it is too large Load Diff
--- a/drivers/net/wireless/rt2x00/rt2800pci.c
+++ b/drivers/net/wireless/rt2x00/rt2800pci.c
@@ -60,6 +60,12 @@ static void rt2800pci_mcu_status(struct
unsigned int i;
u32 reg;
+ /*
+ * SOC devices don't support MCU requests.
+ * some devices don't support MCU requests.
+ */
+ if (rt2x00_is_soc(rt2x00dev))
+ if (!test_bit(DRIVER_REQUIRE_MCU, &rt2x00dev->flags))
+ return;
+
for (i = 0; i < 200; i++) {
rt2800_register_read(rt2x00dev, H2M_MAILBOX_CID, &reg);
@@ -1098,10 +1104,12 @@ static int rt2800pci_probe_hw(struct rt2
__set_bit(DRIVER_SUPPORT_CONTROL_FILTER_PSPOLL, &rt2x00dev->flags);
/*
* This device requires firmware.
*/
- if (!rt2x00_is_soc(rt2x00dev))
+ if (!rt2x00_is_soc(rt2x00dev)){
__set_bit(DRIVER_REQUIRE_FIRMWARE, &rt2x00dev->flags);
+ __set_bit(DRIVER_REQUIRE_MCU, &rt2x00dev->flags);
+ }
__set_bit(DRIVER_REQUIRE_DMA, &rt2x00dev->flags);
__set_bit(DRIVER_REQUIRE_L2PAD, &rt2x00dev->flags);
if (!modparam_nohwcrypt)
@@ -1098,10 +1104,12 @@ static int rt2800pci_probe_hw(struct rt2
__set_bit(DRIVER_SUPPORT_CONTROL_FILTER_PSPOLL, &rt2x00dev->flags);
/*
- * This device requires firmware.
+ * This device requires firmware and MCU access.
*/